summaryrefslogtreecommitdiff
path: root/util.h
diff options
context:
space:
mode:
Diffstat (limited to 'util.h')
-rw-r--r--util.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/util.h b/util.h
index 38c8d2f3ed..87a3f26914 100644
--- a/util.h
+++ b/util.h
@@ -52,7 +52,9 @@ This is a synonym for (! foldEQ_locale())
#define ibcmp(s1, s2, len) cBOOL(! foldEQ(s1, s2, len))
#define ibcmp_locale(s1, s2, len) cBOOL(! foldEQ_locale(s1, s2, len))
-/* perl.h undefs HAS_QUAD if IV isn't 64-bit */
+/* outside the core, perl.h undefs HAS_QUAD if IV isn't 64-bit
+ We can't swap this to HAS_QUAD, because the logic here affects the type of
+ perl_drand48_t below, and that is visible outside of the core. */
#ifdef U64TYPE
# if !defined(_MSC_VER) || _MSC_VER >= 1300
/* use a faster implementation when quads are available,